searchNodes=[{"doc":"The Sock behaviour defines an interface for web servers to flexibly host WebSocket applications. The lifecycle of a WebSocket connection is codified in the structure of this behaviour, and proceeds as follows: First, a client will attempt to Upgrade an HTTP connection to a WebSocket connection by passing a specific set of headers in an HTTP request. A Sock implementation is notified of this via a call to sock_negotiate/2 . The implementation can inspect the request, which is passed as a Plug.Conn structure. It can then choose to accept or refuse the WebSocket upgrade request Assuming the Sock implementation accepted the WebSocket connection, the HTTP connection is then upgraded to a WebSocket connection, and sock_handle_connection/2 is called to notify the implementation that the connection is now live The Sock implementation will then be notified of client data by way of sock_handle_text_frame/3 , sock_handle_binary_frame/3 , sock_handle_ping_frame/3 or sock_handle_pong_frame/3 as appropriate. The Sock implementation is free to send data to the client via the passed in Socket instance at any time At any time, sock_handle_close/3 , sock_handle_error/3 or sock_handle_timeout/2 may be called to indicate a close, error or timeout condition respectively All of the above callbacks take and return a state value, in a manner similar to GenServers. The initial value of this state is that returned from the sock_init/1 callback","ref":"Sock.html","title":"Sock","type":"behaviour"},{"doc":"Called by the web server implementation when binary data is received from the client. The web server implementation will only call this function once a complete binary frame has been received (that is, once any continuation frames have been received). The return value from this callback is handled as described in sock_handle_connection/2","ref":"Sock.html#c:sock_handle_binary_frame/3","title":"Sock.sock_handle_binary_frame/3","type":"callback"},{"doc":"Called by the web server implementation when a connection is being closed due to one of the following reasons: A Sock callback for this connection returned a {:close, state()} tuple. The reason will be {:local, 1000} . The socket connection will still be open in this case The hosting web server is being shut down. The reason will be {:local, 1001} . The socket connection will still be open in this case The client send a connection close frame. The reason will be {:remote, code} , where code is the status code sent by the client (or 1005 is no status code was sent). The socket connection will still be open in this case, although care should be taken of the fact that the client may not be listening any longer The return value from this callback is ignored","ref":"Sock.html#c:sock_handle_close/3","title":"Sock.sock_handle_close/3","type":"callback"},{"doc":"Called by the web server implementation after a WebSocket connection has been established (that is, after sock_negotiate/2 has accepted the connection &amp; the WebSocket handshake has been successfully completed). Implementations can use this callback to eagerly send data to the client, subscribe the client to any relevant subscriptions within the application, or any other task which should be undertaken at the time the connection is established The return value from this callback is handled as follows: {:continue, state()} : The connection is kept open &amp; its state is updated to the returned value {:close, state()} : The connection is closed cleanly &amp; its state is updated to the returned value. sock_handle_close/3 will be subsequently called a reason code of 1000 &amp; the updated state {:error, term(), state()} : The connection is closed abnormally &amp; its state is updated to the returned value. sock_handle_error/3 will be subsequently called with the updated state","ref":"Sock.html#c:sock_handle_connection/2","title":"Sock.sock_handle_connection/2","type":"callback"},{"doc":"Called by the web server implementation when a connection is being closed due to one of the following reasons: A Sock callback for this connection returned an {:error, reason, state()} tuple. The socket connection will still be open in this case The underlying TCP connection was closed unexpectedly. The socket connection will be closed in this case The underlying TCP connection connection encountered an error. The socket connection will be closed in this case The return value from this callback is ignored","ref":"Sock.html#c:sock_handle_error/3","title":"Sock.sock_handle_error/3","type":"callback"},{"doc":"Called by the web server implementation when the socket process receives a GenServer.handle_info/2 call which was not otherwise processed by the server implementation. The return value from this callback is handled as described in sock_handle_connection/2","ref":"Sock.html#c:sock_handle_info/3","title":"Sock.sock_handle_info/3","type":"callback"},{"doc":"Called by the web server implementation when a ping frame has been received from the client. Note that Sock implementation SHOULD NOT send a pong frame in response; this MUST be automatically done by the web server before this callback has been called. The return value from this callback is handled as described in sock_handle_connection/2","ref":"Sock.html#c:sock_handle_ping_frame/3","title":"Sock.sock_handle_ping_frame/3","type":"callback"},{"doc":"Called by the web server implementation when a pong frame has been received from the client. The return value from this callback is handled as described in sock_handle_connection/2","ref":"Sock.html#c:sock_handle_pong_frame/3","title":"Sock.sock_handle_pong_frame/3","type":"callback"},{"doc":"Called by the web server implementation when text data is received from the client. The web server implementation will only call this function once a complete text frame has been received (that is, once any continuation frames have been received). The return value from this callback is handled as described in sock_handle_connection/2","ref":"Sock.html#c:sock_handle_text_frame/3","title":"Sock.sock_handle_text_frame/3","type":"callback"},{"doc":"Called by the web server implementation when a connection has not received any client data for a period of time. The exact details of what this means and any particular timeout values are dependent on the underlying web server implementation. The socket connection will be open in this case. The return value from this callback is ignored","ref":"Sock.html#c:sock_handle_timeout/2","title":"Sock.sock_handle_timeout/2","type":"callback"},{"doc":"Called by a web server implementation to provide initial state for all future connections. The manner by which the user specifies the init_arg value passed into this callback is implementation dependent. The result returned by sock_init/1 is used as the initial state of all connections using the Sock implementation. Note that this callback may be called during compilation and as such it must not return pids, ports or values that are specific to the runtime.","ref":"Sock.html#c:sock_init/1","title":"Sock.sock_init/1","type":"callback"},{"doc":"Called by the web server implementation when a client attempts to upgrade to a WebSocket connection. At this point, the web server has validated that the upgrade request is technically correct (that is, it meets all the requirements laid out in RFC6455§4.1), but this callback is provided in case the Sock implementation wishes to perform further checks before accepting the connection (perhaps by considering the request path or various headers). This call is also the last time that the originating request is accessible by the Sock implementation. Should values from the Plug.Conn request be needed later on in the WebSocket lifecycle, this callback should store such values in the returned connection state. If the Sock implementation wishes to accept this connection, it should return a {:accept, Plug.Conn.t(), state(), [opts()]} tuple. The web server will then perform its half of the connection handshake as outlined in RFC6455§4.2, and subsequently call sock_handle_connection/2 . The Sock implementation MUST NOT send any data on the Plug.Conn connection in this case, or else the handshake will not be able to complete. Valid options to return in the final accept tuple value are as described in the t:negotiate_opts() type. If the Sock implementation wishes to refuse this connection, it should: Create an HTTP response on the Plug.Conn connection describing the reason for refusal Return a {:refuse, Plug.Conn.t(), state()} tuple with the updated conn as a second argument","ref":"Sock.html#c:sock_negotiate/2","title":"Sock.sock_negotiate/2","type":"callback"},{"doc":"Details about why connection is being closed","ref":"Sock.html#t:close_reason/0","title":"Sock.close_reason/0","type":"type"},{"doc":"The result as returned from many sock handle calls","ref":"Sock.html#t:handle_result/0","title":"Sock.handle_result/0","type":"type"},{"doc":"The type of options returned from the sock_negotiate/2 callback. Possible values have the following meanings: timeout : Specifies a value to be used for timeout conditions on this connection","ref":"Sock.html#t:negotiate_opts/0","title":"Sock.negotiate_opts/0","type":"type"},{"doc":"The result as returned from negotiate calls","ref":"Sock.html#t:negotiate_result/0","title":"Sock.negotiate_result/0","type":"type"},{"doc":"The type of state passed into / returned from Sock callbacks","ref":"Sock.html#t:state/0","title":"Sock.state/0","type":"type"},{"doc":"A WebSocket status code","ref":"Sock.html#t:status_code/0","title":"Sock.status_code/0","type":"type"},{"doc":"A protocol to provide the ability for Sock implementations to send data to a connected WebSocket client. An instance of an (otherwise opaque) type conforming to this protocol is passed in to Sock implementations as the first argument of most Sock callbacks.","ref":"Sock.Socket.html","title":"Sock.Socket","type":"protocol"},{"doc":"Sends the specified data to the client as a binary frame(s). An implementation is permitted to send this data as one or more binary / continuation frames at its discretion.","ref":"Sock.Socket.html#send_binary_frame/2","title":"Sock.Socket.send_binary_frame/2","type":"function"},{"doc":"Sends the data to the client within a ping frame.","ref":"Sock.Socket.html#send_ping_frame/2","title":"Sock.Socket.send_ping_frame/2","type":"function"},{"doc":"Sends the data to the client within a pong frame. Note that Sock implementation should not send pong frames in response to ping frames on their own, since the backing implementation is expected to do this automatically. This function is present solely for purpose of proactively sending pong frames as a unidirectional heartbeat per RFC6455§5.3.3.","ref":"Sock.Socket.html#send_pong_frame/2","title":"Sock.Socket.send_pong_frame/2","type":"function"},{"doc":"Sends the specified data to the client as a text frame(s). An implementation is permitted to send this data as one or more text / continuation frames at its discretion.","ref":"Sock.Socket.html#send_text_frame/2","title":"Sock.Socket.send_text_frame/2","type":"function"},{"doc":"","ref":"Sock.Socket.html#t:t/0","title":"Sock.Socket.t/0","type":"type"}]